var NAVTREEINDEX3 =
{
"node_8h.html#af97e4e0860859339a98f01579c7df551":[9,0,32,1],
"node_8h_source.html":[9,0,32],
"page_client.html":[3,3],
"page_client.html#sec_page_client_credentials":[3,3,1],
"page_client.html#sec_page_client_overview":[3,3,0],
"page_client.html#sec_page_client_resources":[3,3,3],
"page_client.html#sec_page_client_types":[3,3,2],
"page_control.html":[5],
"page_control.html#page_control_overview":[5,0],
"page_core.html":[3,1],
"page_core_api.html":[3],
"page_core_api.html#page_core_overview":[3,0],
"page_global.html":[3,2],
"page_iface_pw_core.html":[6,1],
"page_iface_pw_core.html#page_iface_pw_core":[6,1,1],
"page_iface_pw_core.html#page_iface_pw_core_desc":[6,1,0],
"page_link.html":[3,7],
"page_link.html#page_link_overview":[3,7,0],
"page_node.html":[3,5],
"page_node.html#page_node_overview":[3,5,0],
"page_pipewire_protocol.html":[6],
"page_pipewire_protocol.html#page_ifaces_pipewire":[6,0],
"page_port.html":[3,6],
"page_proxy.html":[4,4],
"page_proxy.html#sec_page_proxy_bind":[4,4,3],
"page_proxy.html#sec_page_proxy_core":[4,4,1],
"page_proxy.html#sec_page_proxy_create":[4,4,2],
"page_proxy.html#sec_page_proxy_destroy":[4,4,6],
"page_proxy.html#sec_page_proxy_events":[4,4,5],
"page_proxy.html#sec_page_proxy_methods":[4,4,4],
"page_proxy.html#sec_page_proxy_overview":[4,4,0],
"page_registry.html":[4,5],
"page_registry.html#page_registry_overview":[4,5,0],
"page_remote_api.html":[4],
"page_remote_api.html#sec_remote_api_loop":[4,1],
"page_remote_api.html#sec_remote_api_overview":[4,0],
"page_remote_api.html#sec_remote_api_remote":[4,2],
"page_remote_api.html#ssec_remote_api_proxy":[4,1,0],
"page_remote_api.html#ssec_remote_api_remote_connect":[4,2,1],
"page_remote_api.html#ssec_remote_api_remote_disconnect":[4,2,3],
"page_remote_api.html#ssec_remote_api_remote_registry":[4,2,2],
"page_remote_api.html#ssec_remote_create":[4,2,0],
"page_resource.html":[3,4],
"page_resource.html#sec_page_resource":[3,4,0],
"page_streams.html":[7],
"page_streams.html#sec_buffers":[7,4],
"page_streams.html#sec_connect":[7,2],
"page_streams.html#sec_create":[7,1],
"page_streams.html#sec_format":[7,3],
"page_streams.html#sec_overview":[7,0],
"page_streams.html#sec_stream_disconnect":[7,6],
"page_streams.html#sec_streaming":[7,5],
"page_streams.html#ssec_consume":[7,5,0],
"page_streams.html#ssec_produce":[7,5,1],
"page_streams.html#ssec_stream_formats":[7,2,1],
"page_streams.html#ssec_stream_target":[7,2,0],
"page_thread_loop.html":[4,3],
"page_thread_loop.html#sec_thread_loop_create":[4,3,1],
"page_thread_loop.html#sec_thread_loop_destruction":[4,3,2],
"page_thread_loop.html#sec_thread_loop_events":[4,3,4],
"page_thread_loop.html#sec_thread_loop_locking":[4,3,3],
"page_thread_loop.html#sec_thread_loop_overview":[4,3,0],
"pages.html":[],
"pipewire_8c.html":[9,0,33],
"pipewire_8c.html#a06999a9bd0ec67569e771ef381c37024":[9,0,33,0],
"pipewire_8c.html#a3a41ee3d8c3c6f8bcec7a01485e85770":[9,0,33,2],
"pipewire_8c.html#a5576e00ff68e70c49126208a243460a3":[9,0,33,1],
"pipewire_8c.html#abadaa5454bbccba79adfa316d725e0a2":[9,0,33,4],
"pipewire_8c.html#af2d5f277271ef9f59827ce7ebf0c4378":[9,0,33,3],
"pipewire_8h.html":[9,0,34],
"pipewire_8h.html#a06c879b2d800579f4724109054368d99":[9,0,34,13],
"pipewire_8h.html#a0b5efe6f38693683c07c4495bfcce6c4":[9,0,34,12],
"pipewire_8h.html#a3a41ee3d8c3c6f8bcec7a01485e85770":[9,0,34,9],
"pipewire_8h.html#a4a582dbda1862c28b2eb70f50696cfc3":[9,0,34,7],
"pipewire_8h.html#a4efeba27bea1dc8d9188b8e49b3bd1b0":[9,0,34,1],
"pipewire_8h.html#a5576e00ff68e70c49126208a243460a3":[9,0,34,8],
"pipewire_8h.html#a5cb61aa7df1b5fc780b2df1dd1d576b6":[9,0,34,6],
"pipewire_8h.html#a7f855ab509d6e01e13cf561968a4d1b6":[9,0,34,4],
"pipewire_8h.html#a899cef520412dc30503281f0d7f1f38b":[9,0,34,5],
"pipewire_8h.html#a8b0b569ab7f3457801c61562340be8f8":[9,0,34,2],
"pipewire_8h.html#ab6df08f2eaa6273cbaa019115a3f4646":[9,0,34,3],
"pipewire_8h.html#abadaa5454bbccba79adfa316d725e0a2":[9,0,34,11],
"pipewire_8h.html#acc287aaae982260a49eeac97f27a8227":[9,0,34,0],
"pipewire_8h.html#af2d5f277271ef9f59827ce7ebf0c4378":[9,0,34,10],
"pipewire_8h_source.html":[9,0,34],
"port_8c.html":[9,0,35],
"port_8c.html#a2461fe53d57c257892e36e7d37ae3e24":[9,0,35,8],
"port_8c.html#a265fceb6afcbf35100789c8604adb8ef":[9,0,35,10],
"port_8c.html#a4a6def38ff053282b3b792dc643b12c9":[9,0,35,13],
"port_8c.html#a501ca4956581fbd1a4fe94f3b46d1dec":[9,0,35,9],
"port_8c.html#a53aab0d888eb07c1543dee1c55e5c681":[9,0,35,7],
"port_8c.html#a59a008cb42bb3f7d8bf8aacfbda2a2f2":[9,0,35,12],
"port_8c.html#a6415901538a39fe66d36263ea9ca79cc":[9,0,35,17],
"port_8c.html#a6d61253f97045f6452627a0de7e0a0fc":[9,0,35,2],
"port_8c.html#a771604fa6c4caf93b893e9b8b92f277a":[9,0,35,16],
"port_8c.html#a80e4664aa37f5670d5e3b7859dadc9c6":[9,0,35,3],
"port_8c.html#a8852e0592fc0575a6cf755f00b67f7ef":[9,0,35,4],
"port_8c.html#a9b7232de826fc0179f213900bc387f0c":[9,0,35,1],
"port_8c.html#aa54010051af237b74def97bbee028975":[9,0,35,11],
"port_8c.html#aa5f0d2bacd54660e2d2bf0149f4f256d":[9,0,35,14],
"port_8c.html#aa832bfdbd4b9f74a9d6432f84b587db1":[9,0,35,18],
"port_8c.html#ae4bedd2b2c16b7699ab39f00a00fee38":[9,0,35,15],
"port_8c.html#aeb60e15f509f9a3a8c9b077d0136805f":[9,0,35,5],
"port_8c.html#afe0d495763a810ef23c5a6d128f52794":[9,0,35,6],
"port_8h.html":[9,0,36],
"port_8h.html#a2461fe53d57c257892e36e7d37ae3e24":[9,0,36,7],
"port_8h.html#a265fceb6afcbf35100789c8604adb8ef":[9,0,36,9],
"port_8h.html#a2915d7da381d482996fc9a414843caf5":[9,0,36,2],
"port_8h.html#a2d08d6e2358afc05ca212a0258fb6a26":[9,0,36,3],
"port_8h.html#a501ca4956581fbd1a4fe94f3b46d1dec":[9,0,36,8],
"port_8h.html#a53aab0d888eb07c1543dee1c55e5c681":[9,0,36,6],
"port_8h.html#a6415901538a39fe66d36263ea9ca79cc":[9,0,36,10],
"port_8h.html#a6d61253f97045f6452627a0de7e0a0fc":[9,0,36,5],
"port_8h.html#aa435bb085eeca5a8c0d99313bd9aac24":[9,0,36,1],
"port_8h.html#adbdfd176064e149c49e7c4bbbdd1e3a6":[9,0,36,4],
"port_8h.html#adbdfd176064e149c49e7c4bbbdd1e3a6a0db5ddd15b188c1f747499c8d75f20c2":[9,0,36,4,0],
"port_8h.html#adbdfd176064e149c49e7c4bbbdd1e3a6a15f1ec0a36d9e4f9dd3d7304243044a9":[9,0,36,4,4],
"port_8h.html#adbdfd176064e149c49e7c4bbbdd1e3a6a4198e858d11461bc8b1ce179b579b537":[9,0,36,4,2],
"port_8h.html#adbdfd176064e149c49e7c4bbbdd1e3a6a921e399f53a6dd90a1721022d87931ca":[9,0,36,4,1],
"port_8h.html#adbdfd176064e149c49e7c4bbbdd1e3a6aa7c14a47ade16bad43eef1c39574e6ab":[9,0,36,4,5],
"port_8h.html#adbdfd176064e149c49e7c4bbbdd1e3a6ae71d3a847559a838fe9bd5bf8c07faa2":[9,0,36,4,3],
"port_8h_source.html":[9,0,36],
"properties_8c.html":[9,0,37],
"properties_8h.html":[9,0,38],
"properties_8h.html#a020d2bd083e845bbfa3d2366d8c7ffec":[9,0,38,2],
"properties_8h.html#a8ef83913ccf2abb4432ba0ebd3230516":[9,0,38,9],
"properties_8h.html#a8f7a5b70d523cf25f10495830012492a":[9,0,38,1],
"properties_8h.html#a900f0a2675dc8002cd99863565c38751":[9,0,38,8],
"properties_8h.html#a92deca42395043a47ba2a375a946baf4":[9,0,38,10],
"properties_8h.html#aab902808587304fc502c8f3e7f9f876b":[9,0,38,7],
"properties_8h.html#ac11d34de86e40476b46f614220bf0922":[9,0,38,4],
"properties_8h.html#ad4fb275e74373f07d6d7442b1d59625d":[9,0,38,5],
"properties_8h.html#ad542ebb02328767f362cf90999d428ec":[9,0,38,6],
"properties_8h.html#ae34351cc0fba5efc403f0bf5f19d903c":[9,0,38,3],
"properties_8h_source.html":[9,0,38],
"protocol_8c.html":[9,0,39],
"protocol_8c.html#a0dac7c46c3ffea078e00f23ba75edf80":[9,0,39,6],
"protocol_8c.html#a253136c71f02f82d59fd79c78c40fe65":[9,0,39,1],
"protocol_8c.html#a4b8a7c184d8756e4864538f16a60bec3":[9,0,39,2],
"protocol_8c.html#a515ef2ac9a2e741b04e3301573c7468e":[9,0,39,8],
"protocol_8c.html#a6d58875f54dbf541b969c5911b802311":[9,0,39,3],
"protocol_8c.html#aaba33660d98b865fb0ea4898ab6f8fe8":[9,0,39,7],
"protocol_8c.html#ab10469364d146903d93e85a936a933bb":[9,0,39,0],
"protocol_8c.html#ae14bc734b0ea2f0cd081716a552d3b07":[9,0,39,5],
"protocol_8c.html#aedaad565d0021ebcffe1b8699d150174":[9,0,39,4],
"protocol_8h.html":[9,0,40],
"protocol_8h.html#a0dac7c46c3ffea078e00f23ba75edf80":[9,0,40,24],
"protocol_8h.html#a10397b3ea74c80703140242313ab52df":[9,0,40,12],
"protocol_8h.html#a1667bbb761ac038884e0b08b3ad0113a":[9,0,40,14],
"protocol_8h.html#a253136c71f02f82d59fd79c78c40fe65":[9,0,40,19],
"protocol_8h.html#a3b9d1f2afdf848863a84c7f2c825dc32":[9,0,40,5],
"protocol_8h.html#a4b8a7c184d8756e4864538f16a60bec3":[9,0,40,20],
"protocol_8h.html#a4d8f6852ba390ba826744d18b58c4021":[9,0,40,17],
"protocol_8h.html#a515ef2ac9a2e741b04e3301573c7468e":[9,0,40,26],
"protocol_8h.html#a6673120bfc643d6cbeea97535873b4f0":[9,0,40,9],
"protocol_8h.html#a6c57711ce8eee785b967ed0487a2fe3b":[9,0,40,13],
"protocol_8h.html#a6d58875f54dbf541b969c5911b802311":[9,0,40,21],
"protocol_8h.html#a7ec159e0c7c93a0ba25f391fc828b4cf":[9,0,40,15],
"protocol_8h.html#a91126ea5ca35fb743c9fd04d27316fe1":[9,0,40,11],
"protocol_8h.html#aaba33660d98b865fb0ea4898ab6f8fe8":[9,0,40,25],
"protocol_8h.html#ab10469364d146903d93e85a936a933bb":[9,0,40,18],
"protocol_8h.html#ac2742efc503c7a6e04238bd9a94af35e":[9,0,40,16],
"protocol_8h.html#ad3a30029abadec4f4b76ae2cb28a4585":[9,0,40,8],
"protocol_8h.html#ae14bc734b0ea2f0cd081716a552d3b07":[9,0,40,23],
"protocol_8h.html#aeae48475b735761c22837afd53e2ce9e":[9,0,40,10],
"protocol_8h.html#aedaad565d0021ebcffe1b8699d150174":[9,0,40,22],
"protocol_8h.html#af3f16b337d5388520f01a55d36ecb760":[9,0,40,6],
"protocol_8h.html#afc4c44c0db62c2c03886901ef6f7a4fd":[9,0,40,7],
"protocol_8h_source.html":[9,0,40],
"proxy_8c.html":[9,0,41],
"proxy_8c.html#a01735abb03506ca5b939744c2679e8ae":[9,0,41,0],
"proxy_8c.html#a5950a9b370047e0ac45989a52a2f47ed":[9,0,41,3],
"proxy_8c.html#a9ace4e7667587147f9970d41cafac327":[9,0,41,4],
"proxy_8c.html#aa4790d3d0254680598e0c9a19f9107a3":[9,0,41,2],
"proxy_8c.html#ab74bbe87b946bf5f5189c14203642599":[9,0,41,6],
"proxy_8c.html#ac2ec45e9f68c8d0dadf1d4faa3f9620c":[9,0,41,5],
"proxy_8c.html#adb37da4520e08e93c9f3aa12fb488a75":[9,0,41,1],
"proxy_8h.html":[9,0,42],
"proxy_8h.html#a01735abb03506ca5b939744c2679e8ae":[9,0,42,4],
"proxy_8h.html#a0b83cae9785823f729c34b787d2a915f":[9,0,42,2],
"proxy_8h.html#a5950a9b370047e0ac45989a52a2f47ed":[9,0,42,8],
"proxy_8h.html#a8dd7c3044529e15a8fcc8c1034bbb102":[9,0,42,3],
"proxy_8h.html#a9ace4e7667587147f9970d41cafac327":[9,0,42,9],
"proxy_8h.html#aa4790d3d0254680598e0c9a19f9107a3":[9,0,42,7],
"proxy_8h.html#ab2edf34b4782da73418845309c20c3d8":[9,0,42,12],
"proxy_8h.html#ab74bbe87b946bf5f5189c14203642599":[9,0,42,11],
"proxy_8h.html#ac2ec45e9f68c8d0dadf1d4faa3f9620c":[9,0,42,10],
"proxy_8h.html#adb37da4520e08e93c9f3aa12fb488a75":[9,0,42,5],
"proxy_8h.html#adb7836fa36fc664449def4b9ea27c7ed":[9,0,42,6],
"proxy_8h.html#aefe515d5ef495eaba32fd082dba54256":[9,0,42,1],
"proxy_8h_source.html":[9,0,42],
"remote_8c.html":[9,0,43],
"remote_8c.html#a08cabba9a139d8cbbb00592801290aea":[9,0,43,0],
"remote_8c.html#a092bf29d1cd7cc32233a3daee0764930":[9,0,43,8],
"remote_8c.html#a2449ad8295ff02c72c25ab34feaa0324":[9,0,43,15],
"remote_8c.html#a2d834fb0fdcb7e2174b9c156bcc3fe69":[9,0,43,1],
"remote_8c.html#a345eb6d633bbd8dd6e5f4089a66601db":[9,0,43,12],
"remote_8c.html#a512639c335f32485de2291f03ae03cdc":[9,0,43,3],
"remote_8c.html#a5ea2b8b2674320fb320c5b2c71b0bac2":[9,0,43,5],
"remote_8c.html#a64ccc7fa45e62f41c95942b938a3407b":[9,0,43,13],
"remote_8c.html#a83445c8ddb750ea51175e2b1d955bb6e":[9,0,43,14],
"remote_8c.html#a90de30b9f1762e327e05bf8d6a0047a4":[9,0,43,4],
"remote_8c.html#a92da67f8a9313c37504044486a1d7cb0":[9,0,43,2],
"remote_8c.html#a953d3df17ce9c26bcd790d1b4a5b33d7":[9,0,43,9],
"remote_8c.html#aad3cbf91014d891f30d33c52fc63f7fb":[9,0,43,11],
"remote_8c.html#ad63bfda38e8a40c3c37b44ef82dafd2e":[9,0,43,16],
"remote_8c.html#ad9e26cfa589784bec881c01b34a5444b":[9,0,43,10],
"remote_8c.html#aea761b0969728a0b0e226b568c247f58":[9,0,43,7],
"remote_8c.html#af0a388b2eb3bab3047517754aad8702f":[9,0,43,6],
"remote_8h.html":[9,0,44],
"remote_8h.html#a08cabba9a139d8cbbb00592801290aea":[9,0,44,5],
"remote_8h.html#a092bf29d1cd7cc32233a3daee0764930":[9,0,44,9],
"remote_8h.html#a2449ad8295ff02c72c25ab34feaa0324":[9,0,44,14],
"remote_8h.html#a345eb6d633bbd8dd6e5f4089a66601db":[9,0,44,13],
"remote_8h.html#a4cf01bda13cb7953e6ff0168acecd728":[9,0,44,1],
"remote_8h.html#a5ea2b8b2674320fb320c5b2c71b0bac2":[9,0,44,6],
"remote_8h.html#a953d3df17ce9c26bcd790d1b4a5b33d7":[9,0,44,10],
"remote_8h.html#a9c94072cc14a7702ff7304e3b050edd0":[9,0,44,2],
"remote_8h.html#a9d3d4958e743ad59ba245107a49f2990":[9,0,44,4],
"remote_8h.html#a9d3d4958e743ad59ba245107a49f2990a3e408dc7fd66c3add909d9ba05e67968":[9,0,44,4,2],
"remote_8h.html#a9d3d4958e743ad59ba245107a49f2990a5837f988b1fa15ce4c1e485b082aa52e":[9,0,44,4,0],
"remote_8h.html#a9d3d4958e743ad59ba245107a49f2990abdb3d80d1ecc30413438d5fe7f749498":[9,0,44,4,3],
"remote_8h.html#a9d3d4958e743ad59ba245107a49f2990ac7cb05410928621a69013877b4887a20":[9,0,44,4,1],
"remote_8h.html#aad3cbf91014d891f30d33c52fc63f7fb":[9,0,44,12],
"remote_8h.html#ab0dcc1d685bff01c0d6b7f7a08e66fe7":[9,0,44,3],
"remote_8h.html#ad63bfda38e8a40c3c37b44ef82dafd2e":[9,0,44,15],
"remote_8h.html#ad9e26cfa589784bec881c01b34a5444b":[9,0,44,11],
"remote_8h.html#aea761b0969728a0b0e226b568c247f58":[9,0,44,8],
"remote_8h.html#af0a388b2eb3bab3047517754aad8702f":[9,0,44,7],
"remote_8h_source.html":[9,0,44],
"resource_8c.html":[9,0,45],
"resource_8c.html#a119a41be865f03ef8736977acba8a323":[9,0,45,0],
"resource_8c.html#a332bee9e00671e80bd1d897551aa065d":[9,0,45,8],
"resource_8c.html#a3b307672c5a8939a92829b56d72cc4c9":[9,0,45,3],
"resource_8c.html#a5991b9355bf5bce75ef0333a28f90513":[9,0,45,6],
"resource_8c.html#a7c6de11938397e575506360ba3b8b922":[9,0,45,10],
"resource_8c.html#a91805ad55d5fc0a29b40e9265edf6c09":[9,0,45,1],
"resource_8c.html#aa3b26c60acd0c1d008d294a5885d416c":[9,0,45,13],
"resource_8c.html#aa7213c5651700a4bc6bef6df6cc952e9":[9,0,45,4],
"resource_8c.html#aab37d37e596381fec6da22531f78d7bb":[9,0,45,7],
"resource_8c.html#ab9e159d75b7efe39bd53b64055244092":[9,0,45,2],
"resource_8c.html#ac7d13ba52bc1796d4baca39ddc4a6f0c":[9,0,45,9],
"resource_8c.html#ae022953f35be3767c44de0c43fa572e2":[9,0,45,11],
"resource_8c.html#ae9bc3b4567352269420c480127be7810":[9,0,45,12],
"resource_8c.html#af8fe4859dd6826d5eb6c7e28f5519215":[9,0,45,5],
"resource_8h.html":[9,0,46],
"resource_8h.html#a0e7900f7b5edfb4964190f63704ea5cf":[9,0,46,2],
"resource_8h.html#a119a41be865f03ef8736977acba8a323":[9,0,46,7],
"resource_8h.html#a332bee9e00671e80bd1d897551aa065d":[9,0,46,15],
"resource_8h.html#a3b307672c5a8939a92829b56d72cc4c9":[9,0,46,10]
};
